powered by
The anyflights package supplies a set of functions to generate nycflights13-like datasets and data packages for specified years and airports.
nycflights13
Useful links:
http://github.com/simonpcouch/anyflights
Report bugs at https://github.com/simonpcouch/anyflights/issues