get_airports: Query nycflights13-Like Airports Data
Description
This function generates a dataframe similar to the
airports dataset from nycflights13
for any US airports and time frame. Please
note that, even with a strong internet connection, this function
may take several minutes to download relevant data.
Usage
get_airports(dir = NULL)
Arguments
dir
An optional character string giving the directory
to save datasets in. By default, datasets will not be saved to file.
Value
A data frame with ~1350 rows and 8 variables:
faa
FAA airport code
name
Usual name of the airport
lat, lon
Location of airport
alt
Altitude, in feet
tz
Timezone offset from GMT/UTC
dst
Daylight savings time zone. A = Standard US DST: starts on the
second Sunday of March, ends on the first Sunday of November.
U = unknown. N = no dst.
tzone
IANA time zone, as determined by GeoNames webservice