# NOT RUN {
# grab data on all flights departing from
# Portland International Airport in June 2019 and
# other useful metadata without saving to file
# }
# NOT RUN {
anyflights("PDX", 2018, 6)
# }
# NOT RUN {
# ...or, grab that same data and opt to save the
# file as well! (tempdir() can usually be specified
# as a character string giving the path to a folder)
# }
# NOT RUN {
anyflights("PDX", 2018, 6, tempdir())
# }
# NOT RUN {
# }
Run the code above in your browser using DataLab